==> hazelcast-all-3.6.1-sources.jar: com/hazelcast/map/impl/operation/AddIndexOperationFactory.java <==
/*
 * Copyright (c) 2008-2016, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.operation;

import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.spi.Operation;
import com.hazelcast.spi.OperationFactory;
import java.io.IOException;

public class AddIndexOperationFactory implements OperationFactory {

    private String name;
    private String attributeName;
    private boolean ordered;

    public AddIndexOperationFactory() {
    }

    public AddIndexOperationFactory(String name, String attributeName, boolean ordered) {
        this.name = name;
        this.attributeName = attributeName;
        this.ordered = ordered;
    }

    @Override
    public Operation createOperation() {
        return new AddIndexOperation(name, attributeName, ordered);
    }

    @Override
    public void writeData(ObjectDataOutput out) throws IOException {
        out.writeUTF(name);
        out.writeUTF(attributeName);
        out.writeBoolean(ordered);
    }

    @Override
    public void readData(ObjectDataInput in) throws IOException {
        name = in.readUTF();
        attributeName = in.readUTF();
        ordered = in.readBoolean();
    }
}

==> hazelcast-all-3.8.8-sources.jar: com/hazelcast/map/impl/operation/AddIndexOperationFactory.java <==
/*
 * Copyright (c) 2008-2017, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.map.impl.operation;

import com.hazelcast.map.impl.MapDataSerializerHook;
import com.hazelcast.nio.ObjectDataInput;
import com.hazelcast.nio.ObjectDataOutput;
import com.hazelcast.spi.Operation;

import java.io.IOException;

public class AddIndexOperationFactory extends AbstractMapOperationFactory {

    private String name;
    private String attributeName;
    private boolean ordered;

    public AddIndexOperationFactory() {
    }

    public AddIndexOperationFactory(String name, String attributeName, boolean ordered) {
        this.name = name;
        this.attributeName = attributeName;
        this.ordered = ordered;
    }

    @Override
    public Operation createOperation() {
        return new AddIndexOperation(name, attributeName, ordered);
    }

    @Override
    public void writeData(ObjectDataOutput out) throws IOException {
        out.writeUTF(name);
        out.writeUTF(attributeName);
        out.writeBoolean(ordered);
    }

    @Override
    public void readData(ObjectDataInput in) throws IOException {
        name = in.readUTF();
        attributeName = in.readUTF();
        ordered = in.readBoolean();
    }

    @Override
    public int getId() {
        return MapDataSerializerHook.ADD_INDEX_FACTORY;
    }
}
